.. _Mahdi Moqri: https://github.com/moqri
.. _Martin Perez-Guevara: https://github.com/MartinPerez
.. _Seth Paulson: https://github.com/sarudak

.. _Dayoon Kwon: https://scholar.google.com/citations?user=5L9djqsAAAAJ&hl=en
.. _Albert Ying: https://scholar.google.com/citations?user=JS7AdkcAAAAJ&hl=zh-CN
.. _Alec Eames: https://www.linkedin.com/in/alec-eames-589a3917a/
.. _Mehrnoosh Emamifar: https://www.linkedin.com/in/mehrnoosh-emamifar/
.. _Chancen Law: https://www.linkedin.com/in/chancenlaw/
.. _Nureldin Mohamed: https://www.linkedin.com/in/nureldin-m-19738625b/
.. _Yasamin Jodat: https://www.linkedin.com/in/yasamin-jodat/
.. _Aneesh Mazumder: https://www.linkedin.com/in/aneesh-mazumder/
.. _Marc Balestreri: https://www.linkedin.com/in/marcbal/

.. _AI4Life Institute: https://www.ai4lifeinstitute.com/
